@@ -1,15 +1,24 @@
-from django.core.management.base import BaseCommand
+from django.core.management.base import BaseCommand, CommandError
 
 from django_bundles.core import get_bundles
 from django_bundles.processors import processor_pipeline
 from django_bundles.utils import run_command
 from django_bundles.conf.bundles_settings import bundles_settings
 
+from optparse import make_option
+
 import os
 
 
 class Command(BaseCommand):
     help = "Lints the bundles based on settings.BUNDLES_LINTING"
+    option_list = BaseCommand.option_list + (
+        make_option('--failures-only',
+            action='store_true',
+            default=False,
+            help='Only report failures'
+        ),
+    )
 
     def lint_file(self, filename, bundle_type, bundle_path):
         stdout, stderr = run_command(bundles_settings.BUNDLES_LINTING[bundle_type]['command'] % {
@@ -17,7 +26,8 @@ class Command(BaseCommand):
         })
 
         if (bundles_settings.BUNDLES_LINT_SUCCESS_OK and stdout.strip() == 'OK') or (not bundles_settings.BUNDLES_LINT_SUCCESS_OK and not stdout.strip()):
-            self.stdout.write('OK\t\t%s\n' % bundle_path)
+            if self.show_successes:
+                self.stdout.write('OK\t\t%s\n' % bundle_path)
             failures = 0
         else:
             failures = 1
@@ -27,6 +37,8 @@ class Command(BaseCommand):
         return failures
 
     def handle(self, *args, **options):
+        self.show_successes = not bool(options.get('failures_only'))
+
         failures = 0
         for bundle in get_bundles():
             for bundle_file in bundle.files:
@@ -39,6 +51,6 @@ class Command(BaseCommand):
             failures += self.lint_file(single_file_path, os.path.splitext(single_file_path)[1][1:], single_file_path)
 
         if failures:
-            self.stdout.write('\n%s FILE%s FAILED\n' % (failures, 'S' if failures > 1 else ''))
+            raise CommandError('%s FILE%s FAILED' % (failures, 'S' if failures > 1 else ''))
         else:
-            self.stdout.write('\nSUCCESS\n')
+            self.stdout.write('\nALL FILES PASSED\n')
